if not TinyMeleeStats then return end

local L = LibStub("AceLocale-3.0"):GetLocale("TinyMeleeStats")
local media = LibStub:GetLibrary("LibSharedMedia-3.0")

TinyMeleeStats.fonteffects = {
	["none"] = L["None"],
	["OUTLINE"] = L["OUTLINE"],
	["THICKOUTLINE"] = L["THICKOUTLINE"],
}

function TinyMeleeStats:Options()
	local options = {
		name = "TinyMeleeStats",
	    handler = TinyMeleeStats,
	    type = 'group',
	    args = {
			reset = {
				name = L["Position zur\195\188cksetzen"],
				desc = L["Setzt die Position von TMS zur\195\188ck"],
				type = 'execute',
				func = function() tmsframe:ClearAllPoints() tmsframe:SetPoint("CENTER", UIParent, "CENTER") end,
				disabled = function() return InCombatLockdown() end,
				order = 1,
			},
			lock = {
				name = L["Textzeile sperren"],
				desc = L["Sperrt die Textzeile"],
				type = 'toggle',
				get = function() return self.db.char.FrameLocked end,
				set = function(info, value)				
					if(value) then
						self.db.char.FrameLocked = true
						tmsframe:SetMovable(false)
						fixed = L["|cffFF0000Der Text ist fixiert. Freigeben mit |c00ff00ff/tms |c001E90FF[Textzeile sperren]|cffFF0000!|r"]
						tmsframe:SetScript("OnDragStart", function() DEFAULT_CHAT_FRAME:AddMessage(fixed) end)
					else
						self.db.char.FrameLocked = false
						tmsframe:SetMovable(true)
						tmsframe:SetScript("OnDragStart", function() tmsframe:StartMoving() end)
						tmsframe:SetScript("OnDragStop", function()	tmsframe:StopMovingOrSizing() self.db.char.xPosition = tmsframe:GetLeft() self.db.char.yPosition = tmsframe:GetBottom()	end)
					end
				end,
				disabled = function() return InCombatLockdown() end,
				order = 2,
			},
			record = {
				name = L["Rekordnachrichten"],
				desc = L["Schaltet Rekordnachrichten an/aus"],
				type = 'toggle',
				get = function() return self.db.char.RecordMsg end,
				set = function(info, value)				
					if(value) then
						self.db.char.RecordMsg = true
					else
						self.db.char.RecordMsg = false
					end
				end,
				disabled = function() return InCombatLockdown() end,
				order = 3,
			},
			text = {
				name = L["Text"],
				desc = L["Text Einstellungen"],
				type = 'group',
				order = 1,
				args = {			
					hader = {
						name = L["Text Einstellungen"],
						type = 'header',
						order = 1,
					},
					spaceline1 = {
						name = "\n",
						type = 'description',
						order = 2,
					},
					alpha = {
						name = L["Text Alpha"],
						desc = L["Sichtbarkeit des Textes au\195\159erhalb des Kampfes"],
						width = 'full',
						type = 'range',
						min = 0,
						max = 1,
						step = 0.01,
						isPercent = true,
						get = function() return self.db.char.Vis end,
						set = function(info, newValue)
							self.db.char.Vis = newValue
							tmsframe:SetAlpha(self.db.char.Vis)
						end,
						disabled = function() return InCombatLockdown() end,
						order = 3,
					},
					font = {
						name = L["Schriftart"],
						type = 'select',
						get = function() return self.db.char.Font end,
						set = function(info, newValue)
							self.db.char.Font = newValue
							local font = media:Fetch("font", self.db.char.Font)
							tmsstring:SetFont(font, self.db.char.Size, self.db.char.FontEffect)
						end,
						values = self.fonts,
						order = 4,
					},
					spaceline2 = {
						name = "",
						type = 'description',
						order = 5,
					},
					fonteffect = {
						name = L["Schriftartrand"],
						type = 'select',
						get = function() return self.db.char.FontEffect end,
						set = function(info, newValue)
							self.db.char.FontEffect = newValue
							local font = media:Fetch("font", self.db.char.Font)
							tmsstring:SetFont(font, self.db.char.Size, self.db.char.FontEffect)
						end,
						values = self.fonteffects,
						order = 6,
					},
					barfontsize = {
						name = L["Schriftgr\195\182\195\159e"],
						width = 'full',
						type = 'range',
						min = 6,
						max = 32,
						step = 1,
						get = function() return self.db.char.Size end,
						set = function(info, newValue)
							self.db.char.Size = newValue
							local font = media:Fetch("font", self.db.char.Font)
							tmsstring:SetFont(font, self.db.char.Size, self.db.char.FontEffect)
						end,
						order = 7,
					},
				},
			},
			style = {
				name = L["Stats"],
				desc = L["Definiert die angezeigten Stats"],
				type = 'group',
				order = 2,
				args = {
					hader = {
						name = L["Stats"],
						type = 'header',
						order = 1,
					},
					spaceline3 = {
						name = "\n",
						type = 'description',
						order = 2,
					},
					ap = {
						name = L["Angriffskraft"],
						desc = L["Angriffskraft"].." "..L["ein-/ausblenden"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Ap end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Ap = true
							else
								self.db.char.Style.Ap = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 3,
					},
					crit = {
						name = L["Kritischetrefferchance"],
						desc = L["Kritischetrefferchance"].." "..L["ein-/ausblenden"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Crit end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Crit = true
							else
								self.db.char.Style.Crit = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 4,
					},
					hit = {
						name = L["Trefferchance"],
						desc = L["Trefferchance"].." "..L["ein-/ausblenden"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Hit end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Hit = true
							else
								self.db.char.Style.Hit = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 5,
					},
					speed = {
						name = L["Waffengeschwindigkeit"],
						desc = L["Waffengeschwindigkeit"].." "..L["ein-/ausblenden"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.Speed end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.Speed = true
							else
								self.db.char.Style.Speed = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 6,
					},
					maxap = {
						name = L["H\195\182chste"].." "..L["Angriffskraft"],
						desc = L["H\195\182chste"].." "..L["Angriffskraft"].." "..L["ein-/ausblenden"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.MaxAp end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.MaxAp = true
							else
								self.db.char.Style.MaxAp = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 7,
					},
					maxcrit = {
						name = L["H\195\182chste"].." "..L["Kritischetrefferchance"],
						desc = L["H\195\182chste"].." "..L["Kritischetrefferchance"].." "..L["ein-/ausblenden"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.MaxCrit end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.MaxCrit = true
							else
								self.db.char.Style.MaxCrit = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 8,
					},
					maxhit = {
						name = L["H\195\182chste"].." "..L["Trefferchance"],
						desc = L["H\195\182chste"].." "..L["Trefferchance"].." "..L["ein-/ausblenden"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.MaxHit end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.MaxHit = true
							else
								self.db.char.Style.MaxHit = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 9,
					},
					maxspeed = {
						name = L["H\195\182chste"].." "..L["Waffengeschwindigkeit"],
						desc = L["H\195\182chste"].." "..L["Waffengeschwindigkeit"].." "..L["ein-/ausblenden"],
						width = 'full',
						type = 'toggle',
						get = function() return self.db.char.Style.MaxSpeed end,
						set = function(info, value)				
							if(value) then
								self.db.char.Style.MaxSpeed = true
							else
								self.db.char.Style.MaxSpeed = false
							end
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 10,
					},
					spaceline4 = {
						name = "\n",
						type = 'description',
						order = 11,
					},
					resetrecords = {
						name = L["Rekorde zur\195\188cksetzen"],
						desc = L["Setzt die Rekorde deiner Stats zur\195\188ck"],
						type = 'execute',
						func = function()
							self.db.char.HighestAp = 0
							self.db.char.HighestCrit = "0"
							self.db.char.FastestMh = "500"
							self.db.char.FastestOh = "500"
							self.db.char.HighestHit = "0"
							self:Stats()
						end,
						disabled = function() return InCombatLockdown() end,
						order = 12,
					},
				},
			},
		},
	}
	return options
end
